Module workload

Module workload 

This module is primarily concerned with converting an UnresolvedWorkload into a ResolvedWorkload by resolving all components and their dependencies.

Structs

ResolvedWorkload
A fully resolved workload ready for execution.
UnresolvedWorkload
An unresolved workload that has been initialized but not yet bound to plugins.
WorkloadComponent
A WorkloadComponent is a component that is part of a workload.
WorkloadMetadata
Metadata associated with components and services within a workload.
WorkloadService
A WorkloadService is a component that is part of a workload that runs once, either to completion or for the duration of the workload lifecycle.