WorkloadComponent

Struct WorkloadComponent 

pub struct WorkloadComponent { /* private fields */ }
A WorkloadComponent is a component that is part of a workload.

It contains the actual Component that can be instantiated, the Linker for creating stores and instances, the available VolumeMounts to be passed as filesystem preopens, and the full list of HostPlugins that the component depends on.

Implementations

Source

impl WorkloadComponent

pub fn new( workload_id: impl Into<Arc<str>>, workload_name: impl Into<Arc<str>>, workload_namespace: impl Into<Arc<str>>, component: Component, linker: Linker<Ctx>, volume_mounts: Vec<(PathBuf, VolumeMount)>, local_resources: LocalResources, ) -> Self

Create a new WorkloadComponent with the given workload ID, wasmtime Component, Linker, volume mounts, and instance limits.

pub fn pre_instantiate(&mut self) -> Result<InstancePre<Ctx>>

Pre-instantiate the component to prepare for instantiation.

Methods from Deref<Target = WorkloadMetadata>

pub fn id(&self) -> &str

Returns the unique identifier for this component.

pub fn workload_id(&self) -> &str

Returns the ID of the workload this component belongs to.

pub fn workload_name(&self) -> &str

Returns the name of the workload this component belongs to.

pub fn workload_namespace(&self) -> &str

Returns the namespace of the workload this component belongs to.

pub fn engine(&self) -> &Engine

Returns a reference to the wasmtime engine used to compile this component.

pub fn linker(&mut self) -> &mut Linker<Ctx>

Returns a mutable reference to the component’s linker.

pub fn local_resources(&self) -> &LocalResources

Returns a reference to component local resources.

pub fn plugins( &self, ) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>

Returns a reference to the plugins associated with this component.

pub fn add_plugin( &mut self, id: &'static str, plugin: Arc<dyn HostPlugin + Send + Sync>, )

Adds a HostPlugin to the component.

pub fn with_plugins( &mut self, plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>, )

Replaces all plugins for this component with the provided set.

pub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>

Extracts the ComponentItem::ComponentInstances that the component exports.

pub fn world(&self) -> WitWorld

Computes and returns the WitWorld of this component.