WorkloadMetadata

Struct WorkloadMetadata 

pub struct WorkloadMetadata { /* private fields */ }
Metadata associated with components and services within a workload.

Implementations

Source

impl WorkloadMetadata

pub fn id(&self) -> &str

Returns the unique identifier for this component.

pub fn workload_id(&self) -> &str

Returns the ID of the workload this component belongs to.

pub fn workload_name(&self) -> &str

Returns the name of the workload this component belongs to.

pub fn workload_namespace(&self) -> &str

Returns the namespace of the workload this component belongs to.

pub fn engine(&self) -> &Engine

Returns a reference to the wasmtime engine used to compile this component.

pub fn linker(&mut self) -> &mut Linker<Ctx>

Returns a mutable reference to the component’s linker.

pub fn local_resources(&self) -> &LocalResources

Returns a reference to component local resources.

pub fn plugins( &self, ) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>

Returns a reference to the plugins associated with this component.

pub fn add_plugin( &mut self, id: &'static str, plugin: Arc<dyn HostPlugin + Send + Sync>, )

Adds a HostPlugin to the component.

pub fn with_plugins( &mut self, plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>, )

Replaces all plugins for this component with the provided set.

pub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>

Extracts the ComponentItem::ComponentInstances that the component exports.

pub fn world(&self) -> WitWorld

Computes and returns the WitWorld of this component.