pub struct WorkloadService { /* private fields */ }Expand description
A WorkloadService is a component that is part of a workload that
runs once, either to completion or for the duration of the workload lifecycle.
Implementations
Sourceimpl WorkloadService
impl WorkloadService
Sourcepub fn new(
workload_id: impl Into<Arc<str>>,
workload_name: impl Into<Arc<str>>,
workload_namespace: impl Into<Arc<str>>,
component: Component,
linker: Linker<Ctx>,
volume_mounts: Vec<(PathBuf, VolumeMount)>,
local_resources: LocalResources,
max_restarts: u64,
) -> Self
pub fn new( workload_id: impl Into<Arc<str>>, workload_name: impl Into<Arc<str>>, workload_namespace: impl Into<Arc<str>>, component: Component, linker: Linker<Ctx>, volume_mounts: Vec<(PathBuf, VolumeMount)>, local_resources: LocalResources, max_restarts: u64, ) -> Self
Create a new WorkloadService with the given workload ID,
wasmtime Component, Linker, volume mounts, and instance limits.
Sourcepub fn pre_instantiate(&mut self) -> Result<CommandPre<Ctx>>
pub fn pre_instantiate(&mut self) -> Result<CommandPre<Ctx>>
Pre-instantiate the component to prepare for execution.
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Whether or not the service is currently running.
Methods from Deref<Target = WorkloadMetadata>
Sourcepub fn workload_id(&self) -> &str
pub fn workload_id(&self) -> &str
Returns the ID of the workload this component belongs to.
Sourcepub fn workload_name(&self) -> &str
pub fn workload_name(&self) -> &str
Returns the name of the workload this component belongs to.
Sourcepub fn workload_namespace(&self) -> &str
pub fn workload_namespace(&self) -> &str
Returns the namespace of the workload this component belongs to.
Sourcepub fn engine(&self) -> &Engine
pub fn engine(&self) -> &Engine
Returns a reference to the wasmtime engine used to compile this component.
Sourcepub fn linker(&mut self) -> &mut Linker<Ctx>
pub fn linker(&mut self) -> &mut Linker<Ctx>
Returns a mutable reference to the component’s linker.
Sourcepub fn local_resources(&self) -> &LocalResources
pub fn local_resources(&self) -> &LocalResources
Returns a reference to component local resources.
Sourcepub fn plugins(
&self,
) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>
pub fn plugins( &self, ) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>
Returns a reference to the plugins associated with this component.
Sourcepub fn add_plugin(
&mut self,
id: &'static str,
plugin: Arc<dyn HostPlugin + Send + Sync>,
)
pub fn add_plugin( &mut self, id: &'static str, plugin: Arc<dyn HostPlugin + Send + Sync>, )
Adds a HostPlugin to the component.
Sourcepub fn with_plugins(
&mut self,
plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>,
)
pub fn with_plugins( &mut self, plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>, )
Replaces all plugins for this component with the provided set.
Sourcepub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>
pub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>
Extracts the ComponentItem::ComponentInstances that the component exports.