pub struct LocalResources {
pub memory_limit_mb: i32,
pub cpu_limit: i32,
pub config: HashMap<String, String>,
pub environment: HashMap<String, String>,
pub volume_mounts: Vec<VolumeMount>,
pub allowed_hosts: Vec<String>,
}Expand description
Resource limits and configuration for a component or service. Defines memory, CPU limits, configuration values, and volume mounts.
Fields
memory_limit_mb: i32cpu_limit: i32config: HashMap<String, String>Opaque key-value configuration shared between operator + runtime + plugins. Allows passing arbitrary configuration values to influence implementation behavior for all component interfaces. Example: tracing=disable
environment: HashMap<String, String>volume_mounts: Vec<VolumeMount>allowed_hosts: Vec<String>Trait Implementations
Sourceimpl Clone for LocalResources
impl Clone for LocalResources
Sourcefn clone(&self) -> LocalResources
fn clone(&self) -> LocalResources
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalResources
impl Debug for LocalResources
Sourceimpl Default for LocalResources
impl Default for LocalResources
Sourceimpl PartialEq for LocalResources
impl PartialEq for LocalResources
impl StructuralPartialEq for LocalResources