pub struct Workload {
pub namespace: String,
pub name: String,
pub annotations: HashMap<String, String>,
pub service: Option<Service>,
pub components: Vec<Component>,
pub host_interfaces: Vec<WitInterface>,
pub volumes: Vec<Volume>,
}Expand description
Represents a deployable workload containing one or more WebAssembly components. A workload defines the complete runtime configuration including components, services, interfaces, and volumes.
Fields
namespace: Stringname: Stringannotations: HashMap<String, String>service: Option<Service>components: Vec<Component>host_interfaces: Vec<WitInterface>volumes: Vec<Volume>Trait Implementations
impl StructuralPartialEq for Workload