pub struct Ctx {
pub id: String,
pub component_id: Arc<str>,
pub workload_id: Arc<str>,
pub table: ResourceTable,
pub ctx: WasiCtx,
pub http: WasiHttpCtx,
/* private fields */
}Expand description
The context for a component store and linker, providing access to implementations of:
- wasi@0.2 interfaces
- wasi:http@0.2 interfaces
Fields
id: StringUnique identifier for this component context. This is a uuid::Uuid::new_v4 string.
component_id: Arc<str>The unique identifier for the workload component this instance belongs to
workload_id: Arc<str>The unique identifier for the workload this component belongs to
table: ResourceTableThe resource table used to manage resources in the Wasmtime store.
ctx: WasiCtxThe WASI context used to provide WASI functionality to the components using this context.
http: WasiHttpCtxThe HTTP context used to provide HTTP functionality to the component.
Implementations
Sourceimpl Ctx
impl Ctx
Sourcepub fn get_plugin<T: HostPlugin + 'static>(
&self,
plugin_id: &str,
) -> Option<Arc<T>>
pub fn get_plugin<T: HostPlugin + 'static>( &self, plugin_id: &str, ) -> Option<Arc<T>>
Get a plugin by its string ID and downcast to the expected type