This module is primarily concerned with converting an UnresolvedWorkload into a ResolvedWorkload by
resolving all components and their dependencies.
Structs
- Resolved
Workload - A fully resolved workload ready for execution.
- Unresolved
Workload - An unresolved workload that has been initialized but not yet bound to plugins.
- Workload
Component - A
WorkloadComponentis a component that is part of a workload. - Workload
Metadata - Metadata associated with components and services within a workload.
- Workload
Service - A
WorkloadServiceis a component that is part of a workload that runs once, either to completion or for the duration of the workload lifecycle.