pub struct WorkloadMetadata { /* private fields */ }Expand description
Metadata associated with components and services within a workload.
Implementations
Sourceimpl WorkloadMetadata
impl WorkloadMetadata
Sourcepub fn workload_id(&self) -> &str
pub fn workload_id(&self) -> &str
Returns the ID of the workload this component belongs to.
Sourcepub fn workload_name(&self) -> &str
pub fn workload_name(&self) -> &str
Returns the name of the workload this component belongs to.
Sourcepub fn workload_namespace(&self) -> &str
pub fn workload_namespace(&self) -> &str
Returns the namespace of the workload this component belongs to.
Sourcepub fn engine(&self) -> &Engine
pub fn engine(&self) -> &Engine
Returns a reference to the wasmtime engine used to compile this component.
Sourcepub fn linker(&mut self) -> &mut Linker<Ctx>
pub fn linker(&mut self) -> &mut Linker<Ctx>
Returns a mutable reference to the component’s linker.
Sourcepub fn local_resources(&self) -> &LocalResources
pub fn local_resources(&self) -> &LocalResources
Returns a reference to component local resources.
Sourcepub fn plugins(
&self,
) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>
pub fn plugins( &self, ) -> &Option<HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>>
Returns a reference to the plugins associated with this component.
Sourcepub fn add_plugin(
&mut self,
id: &'static str,
plugin: Arc<dyn HostPlugin + Send + Sync>,
)
pub fn add_plugin( &mut self, id: &'static str, plugin: Arc<dyn HostPlugin + Send + Sync>, )
Adds a HostPlugin to the component.
Sourcepub fn with_plugins(
&mut self,
plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>,
)
pub fn with_plugins( &mut self, plugins: HashMap<&'static str, Arc<dyn HostPlugin + Send + Sync>>, )
Replaces all plugins for this component with the provided set.
Sourcepub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>
pub fn component_exports(&self) -> Result<Vec<(String, ComponentItem)>>
Extracts the ComponentItem::ComponentInstances that the component exports.