pub struct Host { /* private fields */ }Expand description
A wasmcloud host that manages WebAssembly workloads and plugins.
The Host is the primary runtime for executing workloads. It manages:
- An engine for compiling and running WebAssembly components
- A collection of workloads and their states
- Plugins that extend host functionality
- System monitoring and resource tracking
Implementations
Sourceimpl Host
impl Host
Sourcepub fn builder() -> HostBuilder
pub fn builder() -> HostBuilder
Create a new builder for the host.
Sourcepub async fn stop(self: Arc<Self>) -> Result<()>
pub async fn stop(self: Arc<Self>) -> Result<()>
Stop the host and shut down all plugins.
Attempts to gracefully stop all plugins with a 3-second timeout for each. Errors are logged but don’t prevent other plugins from being stopped.
Returns
Ok if the shutdown process completes (even with plugin errors).
Sourcepub fn friendly_name(&self) -> &str
pub fn friendly_name(&self) -> &str
Sourcepub fn wit_world(&self) -> WitWorld
pub fn wit_world(&self) -> WitWorld
Returns the WIT (imports, exports) that this host can provide to any component.
Put another way, this represents a simplified version of the host world. For example, this WIT world:
package wasmcloud:host@0.1.0;
interface foo {
...
}
interface bar {
...
}
world host {
import foo;
export bar;
}Would be returned as: ( vec![WitInterface { namespace: “wasmcloud”, package: “host”, interfaces: [“foo”], version: Some(“0.1.0”) }], vec![WitInterface { namespace: “wasmcloud”, package: “host”, interfaces: [“bar”], version: Some(“0.1.0”) }], )
This can be viewed as an inversion of the worlds that this host can support. In the above example,
this host can support any component that imports bar and exports foo. Other exports will be ignored,
and other imports that are unsatisfied will be rejected.