pub struct HostBuilder { /* private fields */ }Expand description
Builder for the Host
Implementations
Sourceimpl HostBuilder
impl HostBuilder
pub fn new() -> Self
pub fn with_engine(self, engine: Engine) -> Self
pub fn with_plugin<T: HostPlugin>(self, plugin: Arc<T>) -> Result<Self>
Sourcepub fn with_hostname(self, hostname: impl AsRef<str>) -> Self
pub fn with_hostname(self, hostname: impl AsRef<str>) -> Self
Sourcepub fn with_friendly_name(self, name: impl AsRef<str>) -> Self
pub fn with_friendly_name(self, name: impl AsRef<str>) -> Self
Sourcepub fn build(self) -> Result<Host>
pub fn build(self) -> Result<Host>
Builds and returns a configured Host.
This method finalizes the configuration and creates the host. If no engine is provided, a default engine is created. If no hostname is provided, the system hostname is used. If no friendly name is provided, a random name is generated.
Returns
A new Host instance ready to be started.
Errors
Returns an error if the default engine cannot be created (when no engine is provided).