pub struct WitWorld {
pub imports: HashSet<WitInterface>,
pub exports: HashSet<WitInterface>,
}Expand description
A collection of WIT interfaces representing a world definition.
A WIT world describes the imports and exports that a component or plugin provides. This is used for capability matching between workloads and plugins.
Fields
imports: HashSet<WitInterface>The interfaces that this world imports (requires from the host)
exports: HashSet<WitInterface>The interfaces that this world exports (provides to the host)
Implementations
Sourceimpl WitWorld
impl WitWorld
Sourcepub fn includes(&self, interface: &WitInterface) -> bool
pub fn includes(&self, interface: &WitInterface) -> bool
This function checks if the world includes a specific interface. This is
slightly different than checking directly against the imports or exports
because it takes into account the possibility of interface nesting and
versioning. See WitInterface::contains for more details.
Sourcepub fn includes_bidirectional(&self, interface: &WitInterface) -> bool
pub fn includes_bidirectional(&self, interface: &WitInterface) -> bool
This function checks if the world includes a specific interface. This is
different than WitWorld::includes because it considers that in one
WitInterface there may be both imports and exports.
Sourcepub fn satisfies(&self, guest: &WitWorld) -> bool
pub fn satisfies(&self, guest: &WitWorld) -> bool
Checks if a guest world (imports) can be satisfied by a host world (exports).
A host world satisfies a guest world if all interfaces required by the guest are provided by the host, considering interface containment (subset/superset) and ignoring any additional interfaces or versions in the host.
Arguments
guest- The guest world to check
Returns
true if the host world (self) provides all interfaces required by the guest world
through direct exports or through superset relationships.